package com.zipcodewilmington.bankaccountlab;

import java.util.Scanner;

public class ATM {
    Scanner scanner = new Scanner(System.in);

    public void runATM(){
        System.out.println("Insert ATM Card");
        String ATMCardNumber = scanner.nextLine();
        AccountHolder[] accountHolders = loadAllAccountHolders();
        AccountHolder accountHolder = lookUpAccountHolder(accountHolders, ATMCardNumber);
        System.out.println("Enter pin number:");
        String pinNumber = scanner.nextLine();
        boolean accountHolderVerified = verifyPinNumber(accountHolder, pinNumber);

        if(accountHolderVerified) {
            BankAccount[] bankAccounts = loadBankAccounts(accountHolder);
            System.out.println("Which account would you like to access: checking, savings, or business?");
            String accountChoice = scanner.nextLine();
            BankAccount accessedAccount = accessBankAccount(bankAccounts,accountChoice);
            System.out.println("What would you like to do: deposit, withdraw, get balance?");
            String actionChoice = scanner.nextLine();
            performAction(accessedAccount, actionChoice);
            System.out.println("Your balance is now: " + accessedAccount.getBalance());
        }

        System.out.println("Please insert ATM card again to make another change");
    }

    public AccountHolder[] loadAllAccountHolders(){
        AccountHolders accountHolders = new AccountHolders();
        accountHolders.loadAccountHolderArrayFromDataBase();
        return accountHolders.getAccountHolderArray();
    }

    public AccountHolder lookUpAccountHolder(AccountHolder[] accountHolders, String ATMCardNumber){
        for (AccountHolder a : accountHolders){
            if (a.getATMCardNumber().equals(ATMCardNumber)){
                return a;
            }
        }
        return null;
    }

    public boolean verifyPinNumber(AccountHolder accountHolder, String pinNumber){
        if (accountHolder.getPinNumber().equals(pinNumber)){
            return true;
        } else {
            return false;
        }
    }

    public BankAccount[] loadBankAccounts(AccountHolder accountHolder){
        return accountHolder.getBankAccountArray();
    }

    public BankAccount accessBankAccount(BankAccount[] bankAccounts, String accountType) {
        if(accountType.equals("checking")){
            for (BankAccount b : bankAccounts){
                if (b instanceof CheckingAccount){
                    return b;
                }
            }
        } else if (accountType.equals("savings")){
            for (BankAccount b : bankAccounts){
                if (b instanceof SavingsAccount){
                    return b;
                }
            }
        } else {
            for (BankAccount b : bankAccounts){
                if (b instanceof BusinessAccount) {
                    return b;
                }
            }
        }
        return null;
    }

    public Double performAction(BankAccount bankAccount, String actionChoice){
        if(actionChoice.equals("deposit")){
            System.out.println("How much would you like to deposit?");
            Double depositAmount = Double.parseDouble(scanner.nextLine());
            Double newBalance = depositToAccount(bankAccount, depositAmount);
        } else if (actionChoice.equals("withdraw")) {
            System.out.println("How much would you like to withdraw?");
            Double withdrawAmount = Double.parseDouble(scanner.nextLine());
            Double newBalance = withdrawFromAccount(bankAccount, withdrawAmount);
        }
        return bankAccount.getBalance();
    }

    public Double depositToAccount(BankAccount bankAccount, Double depositAmount){
        bankAccount.deposit(depositAmount);
        return bankAccount.getBalance();
    }

    public Double withdrawFromAccount(BankAccount bankAccount, Double withdrawAmount){
        bankAccount.withdraw(withdrawAmount);
        return bankAccount.getBalance();
    }

    public Double getBalanceFromAccount(BankAccount bankAccount){
        return bankAccount.getBalance();
    }


}
