package com.zipcodewilmington.bankaccountlab;

import org.junit.Test;

import static org.junit.Assert.*;

public class ATMTest {

    //Start ATM
    public void runATMTest() {
    }

    //Load all account holders to atm
    @Test
    public void loadAllAccountHoldersTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        //Actual
        boolean actual = accountHolders instanceof AccountHolder[];
        //Test
        assertTrue(actual);
    }

    //Look up Account by Account number
    @Test
    public void lookUpAccountHolderTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        String ATMCardNumber = "abc";
        //Actual
        AccountHolder actual = atm.lookUpAccountHolder(accountHolders, ATMCardNumber);
        //Expected
        AccountHolder expected = accountHolders[0];
        //Test
        assertEquals(expected,actual);
    }

    //Verify pin number of account
    @Test
    public void verifyPinNumberTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = atm.lookUpAccountHolder(accountHolders,"abc");
        String pinNumber = "1234";
        //Actual
        Boolean actual = atm.verifyPinNumber(testAccountHolder, pinNumber);
        //Test
        assertTrue(actual);
    }

    //Load all bank accounts for account holder
    @Test
    public void loadBankAccountsTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = accountHolders[0];
        BankAccount[] testBankAccounts = atm.loadBankAccounts(testAccountHolder);
        //Actual
        boolean actual = testBankAccounts instanceof BankAccount[];
        //Test
        assertTrue(actual);
    }

    //Access bank account based on account type (each account holder can only
    //have 1 instance of each type
    @Test
    public void accessBankAccountTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = accountHolders[0];
        BankAccount[] testBankAccounts = atm.loadBankAccounts(testAccountHolder);
        BankAccount testBankAccount = atm.accessBankAccount(testBankAccounts, "checking");
        //Actual
        boolean actual = testBankAccount instanceof CheckingAccount;
        //Test
        assertTrue(actual);
    }

    //Deposit to account of choice
    @Test
    public void depositToAccountTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = accountHolders[0];
        BankAccount[] testBankAccounts = atm.loadBankAccounts(testAccountHolder);
        BankAccount testBankAccount = atm.accessBankAccount(testBankAccounts, "checking");
        Double actual = atm.depositToAccount(testBankAccount, 100.0);
        //Expected
        Double expected = 300.0;
        //Test
        assertEquals(actual, expected);
    }

    //Withdraw from account of choice
    @Test
    public void withdrawFromAccountTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = accountHolders[0];
        BankAccount[] testBankAccounts = atm.loadBankAccounts(testAccountHolder);
        BankAccount testBankAccount = atm.accessBankAccount(testBankAccounts, "checking");
        Double actual = atm.withdrawFromAccount(testBankAccount, 100.0);
        //Expected
        Double expected = 100.0;
        //Test
        assertEquals(actual, expected);
    }

    //Get Balance of account of choice
    @Test
    public void getBalanceFromAccountTest(){
        //Given
        ATM atm = new ATM();
        AccountHolder[] accountHolders = atm.loadAllAccountHolders();
        AccountHolder testAccountHolder = accountHolders[0];
        BankAccount[] testBankAccounts = atm.loadBankAccounts(testAccountHolder);
        BankAccount testBankAccount = atm.accessBankAccount(testBankAccounts, "checking");
        Double actual = atm.getBalanceFromAccount(testBankAccount);
        //Expected
        Double expected = 200.0;
        //Test
        assertEquals(actual, expected);
    }
}